package com.ebts.generator.controller;

import java.io.Serializable;
import java.util.List;

import com.ebts.common.annotation.Log;
import com.ebts.common.core.controller.BaseController;
import com.ebts.common.core.entity.AjaxResult;
import com.ebts.common.enums.BusinessType;
import com.ebts.common.utils.ServerResult;
import com.ebts.common.utils.poi.ExcelUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ebts.generator.entity.ApiClass;
import com.ebts.generator.service.ApiClassService;

/**
 * 接口类名Controller
 *
 * @author binlin
 * @date 2021-01-24
 */
@RestController
@RequestMapping("/tool/apiclass")
public class ApiClassController extends BaseController {
    protected final Logger logger = LoggerFactory.getLogger(ApiClassController.class);

    @Autowired
    private ApiClassService apiClassService;


    /**
     * 获取到api类的select选项
     *
     * @return
     */
    @PreAuthorize("@ebts.hasAnyPermi('tool:apiclass:querylist')")
    @GetMapping("querylist")
    public AjaxResult queryList() {
        ServerResult<List<ApiClass>> ServerResult = apiClassService.selectApiclassList(new ApiClass());
        if (ServerResult.isStart()) {
            return AjaxResult.success(ServerResult.getData());
        } else {
            return AjaxResult.error(ServerResult.getMsg());
        }
    }

    /**
     * 查询接口类名列表
     */
    @PreAuthorize("@ebts.hasPermi('tool:apiclass:list')")
    @GetMapping("/list")
    public Serializable list(ApiClass apiclass) {
        startPage();
        ServerResult<List<ApiClass>> ServerResult = apiClassService.selectApiclassList(apiclass);
        if (ServerResult.isStart()) {
            return getDataTable(ServerResult.getData());
        } else {
            return AjaxResult.info(ServerResult.getMsg());
        }
    }

    /**
     * 导出接口类名列表
     */
    @PreAuthorize("@ebts.hasPermi('tool:apiclass:export')")
    @Log(title = "接口类名", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(ApiClass apiclass) {
        ServerResult<List<ApiClass>> ServerResult = apiClassService.selectApiclassList(apiclass);
        ExcelUtil<ApiClass> util = new ExcelUtil<>(ApiClass.class);
        if (ServerResult.isStart()) {
            return util.exportExcel(ServerResult.getData(), "apiclass");
        } else {
            return AjaxResult.error(ServerResult.getMsg());
        }
    }

    /**
     * 获取接口类名详细信息
     */
    @PreAuthorize("@ebts.hasPermi('tool:apiclass:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        ServerResult<ApiClass> ServerResult = apiClassService.selectApiclassById(id);
        if (ServerResult.isStart()) {
            return AjaxResult.success(ServerResult.getData());
        } else {
            return AjaxResult.info(ServerResult.getMsg());
        }
    }

    /**
     * 新增接口类名
     */
    @PreAuthorize("@ebts.hasPermi('tool:apiclass:add')")
    @Log(title = "接口类名", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ApiClass apiclass) {
        if (apiclass.getmId() == null || apiclass.getmId() < 0) {
            return AjaxResult.error("模块id不能为空!");
        }
        if (apiclass.getcName() == null || apiclass.getcName().equals("")) {
            return AjaxResult.error("类名不能为空!");
        }
        if (apiclass.getcDescribe() == null || apiclass.getcDescribe().equals("")) {
            return AjaxResult.error("类描述不能为空!");
        }
        ServerResult<Integer> ServerResult = apiClassService.insertApiclass(apiclass);
        if (ServerResult.isStart()) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error(ServerResult.getMsg());
        }
    }

    /**
     * 修改接口类名
     */
    @PreAuthorize("@ebts.hasPermi('tool:apiclass:edit')")
    @Log(title = "接口类名", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ApiClass apiclass) {
        if (apiclass.getmId() == null || apiclass.getmId() < 0) {
            return AjaxResult.error("模块id不能为空!");
        }
        if (apiclass.getcName() == null || apiclass.getcName().equals("")) {
            return AjaxResult.error("类名不能为空!");
        }
        if (apiclass.getcDescribe() == null || apiclass.getcDescribe().equals("")) {
            return AjaxResult.error("类描述不能为空!");
        }
        ServerResult<Integer> ServerResult = apiClassService.updateApiclass(apiclass);
        if (ServerResult.isStart()) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error(ServerResult.getMsg());
        }
    }

    /**
     * 删除接口类名
     */
    @PreAuthorize("@ebts.hasPermi('tool:apiclass:remove')")
    @Log(title = "接口类名", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        if (ids.length < 0) {
            return AjaxResult.error("id不能为空!");
        }
        ServerResult<Integer> ServerResult = apiClassService.deleteApiclassByIds(ids);
        if (ServerResult.isStart()) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error(ServerResult.getMsg());
        }
    }
}
